@@ -13,21 +13,20 @@
 # You should have received a copy of the GNU General Public License
 # along with openreviewio-py.  If not, see <https://www.gnu.org/licenses/>
 
-
 from __future__ import annotations
+
+from datetime import datetime
+import operator
 from pathlib import Path
 import shutil
-import operator
 import warnings
-import tempfile
-from datetime import datetime
 from typing import List, Union
 from .Status import Status
 from .Note import Note
-from . import Content
+from . import logging
 
 import lxml.etree as ET
-from inspect import getmembers, isclass
+from inspect import getmembers
 
 
 class MediaReview:
@@ -251,8 +250,9 @@ class MediaReview:
                     import string
 
                     string_to_clean = params.get("body")
-                    printable = set(string.printable)
-                    params["body"] = "".join([s for s in string_to_clean if s in string.printable])
+                    params["body"] = "".join(
+                        [s for s in string_to_clean if s in string.printable]
+                    )
 
                     content = ET.Element(c.__class__.__name__, params)
 
@@ -284,7 +284,10 @@ class MediaReview:
                 target.parent.mkdir()
 
             if not target.is_file():
-                shutil.copy2(source, target)
+                if source.is_file():  # Copy if file exists
+                    shutil.copy2(source, target)
+                else:  # Warn the user
+                    logging.warning(f"Source file to copy doesn't exist: {source}")
 
         return review_folder
 
