@@ -13,16 +13,19 @@
 # You should have received a copy of the GNU General Public License
 # along with openreviewio-py.  If not, see <https://www.gnu.org/licenses/>
 
+import logging
 from typing import Union
 from pathlib import Path
 from . import Content
-from .Content import TextComment, Image, ImageAnnotation
+from .Content import TextComment, Image, ImageAnnotation, TextAnnotation
 from .Note import Note
 from .Status import Status, allowed_statuses
 from .MediaReview import MediaReview
 
 import lxml.etree as ET
 
+logging.basicConfig(format='%(levelname)s: %(message)s')
+
 
 def load_media_review(media_review_path: Union[str, Path]) -> MediaReview:
     """Build a MediaReview object from the written media review at the given path.
